@@ -41,7 +41,8 @@ class RemoteWorkflowGroupService(WorkflowGroupService):
             'GROUP_ID': default_labels.GROUP_ID,
             'GROUP_NAME': default_labels.GROUP_NAME,
             'GROUP_MEMBERS': default_labels.GROUP_MEMBERS,
-            'GROUP_PARAMETERS': default_labels.GROUP_PARAMETERS
+            'GROUP_PARAMETERS': default_labels.GROUP_PARAMETERS,
+            'ENGINE_CONFIG': default_labels.ENGINE_CONFIG
         }
         if labels is not None:
             self.labels.update(labels)
@@ -50,7 +51,8 @@ class RemoteWorkflowGroupService(WorkflowGroupService):
 
     def create_group(
         self, workflow_id: str, name: str, members: Optional[List[str]] = None,
-        parameters: Optional[List[Parameter]] = None, identifier: Optional[str] = None
+        parameters: Optional[List[Parameter]] = None,
+        engine_config: Optional[Dict] = None, identifier: Optional[str] = None
     ) -> Dict:
         """Create a new user group for a given workflow. Each group has a
         a unique name for the workflow, and an optional list of additional
@@ -71,6 +73,9 @@ class RemoteWorkflowGroupService(WorkflowGroupService):
         parameters: list of flowserv.model.parameter.base.Parameter, default=None
             Optional list of parameter declarations that are used to modify the
             template parameters for submissions of the created group.
+        engine_config: dict, default=None
+            Optional configuration settings that will be used as the default
+            when running a workflow.
         identifier: string, default=None
             Optional user-provided group identifier.
 
@@ -86,6 +91,8 @@ class RemoteWorkflowGroupService(WorkflowGroupService):
             data[self.labels['GROUP_PARAMETERS']] = [p.to_dict() for p in parameters]
         if identifier is not None:
             data[self.labels['GROUP_ID']] = identifier
+        if engine_config is not None:
+            data[self.labels['ENGINE_CONFIG']] = engine_config
         return post(url=self.urls(route.GROUPS_CREATE, workflowId=workflow_id), data=data)
 
     def delete_group(self, group_id: str):
